<?php

namespace Drupal\opensearchtab\Controller;

use Symfony\Component\HttpFoundation\Response;

/**
 * OpenSearchDescriptionController .
 */
class OpenSearchDescriptionController {

  /**
   * {@inheritdoc}
   */
  public function content() {
    // Prepare variables for the XML content.
    $config = \Drupal::config('system.site');
    $ost_config = \Drupal::config('opensearchtab.settings');
    $short_name = !empty($ost_config->get('shortname')) ? $ost_config->get('shortname') : (!empty($config->get('name')) ? $config->get('name') : 'Drupal site');
    $description = !empty($ost_config->get('description')) ? $ost_config->get('description') : (!empty($config->get('slogan')) ? $config->get('slogan') : 'Search the site');
    $search_form_path = !empty($ost_config->get('search-form-path')) ? \Drupal::request()->getSchemeAndHttpHost() . $ost_config->get('search-form-path') : \Drupal::request()->getSchemeAndHttpHost() . '/search/node';
    $search_path = !empty($ost_config->get('search-path')) ? \Drupal::request()->getSchemeAndHttpHost() . $ost_config->get('search-path') : \Drupal::request()->getSchemeAndHttpHost() . '/search/node?keys={searchTerms}';
    $suggestions_path_json = !empty($ost_config->get('suggestions-path-json')) ? \Drupal::request()->getSchemeAndHttpHost() . $ost_config->get('suggestions-path-json') : '';
    $suggestions_path_xml = !empty($ost_config->get('suggestions-path-xml')) ? \Drupal::request()->getSchemeAndHttpHost() . $ost_config->get('suggestions-path-xml') : '';
    $favicon_path = !empty($ost_config->get('favicon-path')) ? \Drupal::request()->getSchemeAndHttpHost() . $ost_config->get('favicon-path') : '';

    // Define the XML content.
    $openTag = new \SimpleXMLElement('<OpenSearchDescription></OpenSearchDescription>');
    $openTag->addAttribute('xmlns', 'http://a9.com/-/spec/opensearch/1.1/');
    $openTag->addAttribute('xmlns:xmlns:moz', 'http://www.mozilla.org/2006/browser/search/');
    $openTag->addChild('ShortName', $short_name);
    $openTag->addChild('Description', $description);
    $searchUrl = $openTag->addChild('Url');
    $searchUrl->addAttribute('type', 'text/html');
    $searchUrl->addAttribute('method', 'get');
    $searchUrl->addAttribute('template', $search_path);
    if ($suggestions_path_json !== '') {
      $suggestionsUrl = $openTag->addChild('Url');
      $suggestionsUrl->addAttribute('type', 'application/x-suggestions+json');
      $suggestionsUrl->addAttribute('method', 'get');
      $suggestionsUrl->addAttribute('template', $suggestions_path_json);
    }
    if ($suggestions_path_xml !== '') {
      $suggestionsUrl = $openTag->addChild('Url');
      $suggestionsUrl->addAttribute('type', 'application/x-suggestions+xml');
      $suggestionsUrl->addAttribute('method', 'get');
      $suggestionsUrl->addAttribute('template', $suggestions_path_xml);
    }
    if ($favicon_path !== '') {
      $faviconUrl = $openTag->addChild('Image', $favicon_path);
      $faviconUrl->addAttribute('height', '16');
      $faviconUrl->addAttribute('width', '16');
      $faviconUrl->addAttribute('type', 'image/x-icon');
    }
    $openTag->addChild('xmlns:moz:SearchForm', $search_form_path);

    // Prepare the response.
    $response = new Response();
    $response->setContent($openTag->asXML());
    $response->headers->set('Content-type', 'text/xml');

    return $response;
  }

}
