<?php

namespace Drupal\opensearchtab\Tests;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests the settings form.
 *
 * @group search
 * @group opensearchtab
 */
class OpenSearchDescriptionTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['opensearchtab'];

  /**
   * A simple user with 'access content' permission
   */
  private $user;

  /**
   * Default theme.
   *
   * See: https://www.drupal.org/node/3083055
   *
   * @var string
   */
  protected $defaultTheme = 'stark';

  /**
   * Perform any initial set up tasks that run before every test method.
   */
  public function setUp() {
    parent::setUp();
    $this->user = $this->drupalCreateUser(array('access content'));
    $this->config = \Drupal::configFactory()->getEditable('opensearchtab.settings');
    $this->config
      ->set('search-form-path', '/my-search')
      ->set('search-path', '/my-search?{searchTerms}')
      ->set('suggestions-path-json', '/suggestions?{searchTerms}')
      ->set('suggestions-path-xml', '/suggestions?{searchTerms}')
      ->set('shortname', 'My site')
      ->set('description', 'My site search')
      ->set('favicon-path', '/themes/contrib/mytheme/favicon.ico')
      ->save();
  }

  /**
   * Test open search description.
   *
   * Test, that the the page exists and all XML tags are correctly displayed.
   */
  public function testOpenSearchDescription() {
    $this->drupalLogin($this->user);
    
    // Display the open search description page.
    $this->drupalGet('opensearchdescription');
    $this->assertResponse(200);

    // Test the tags.
    $this->assertRaw('<OpenSearchDescription xmlns="http://a9.com/-/spec/opensearch/1.1/" xmlns:moz="http://www.mozilla.org/2006/browser/search/">');
    $this->assertRaw('</OpenSearchDescription>');
    $this->assertRaw('<ShortName>My site</ShortName>');
    $this->assertRaw('<Description>My site search</Description>');
    $this->assertRaw('<Url type="text/html" method="get" template="' . \Drupal::request()->getSchemeAndHttpHost() . '/my-search?{searchTerms}"/>');
    $this->assertRaw('<Url type="application/x-suggestions+json" method="get" template="' . \Drupal::request()->getSchemeAndHttpHost() . '/suggestions?{searchTerms}"/>');
    $this->assertRaw('<Url type="application/x-suggestions+xml" method="get" template="' . \Drupal::request()->getSchemeAndHttpHost() . '/suggestions?{searchTerms}"/>');
    $this->assertRaw('<moz:SearchForm>' . \Drupal::request()->getSchemeAndHttpHost() . '/my-search</moz:SearchForm>');
    $this->assertRaw('<Image height="16" width="16" type="image/x-icon">' . \Drupal::request()->getSchemeAndHttpHost() . '/themes/contrib/mytheme/favicon.ico</Image>');
  }

}
